@@ -9,7 +9,7 @@ use base qw( Log::Dispatch::Email );
 
 use Mail::Send;
 
-our $VERSION = '2.25';
+our $VERSION = '2.26';
 
 sub send_email
 {
@@ -51,15 +51,16 @@ Log::Dispatch::Email::MailSend - Subclass of Log::Dispatch::Email that uses the
 
 =head1 SYNOPSIS
 
+  use Log::Dispatch;
+
   my $log =
       Log::Dispatch->new
           ( outputs =>
-            [ 'Email::MailSend' =>
-                  { min_level => 'emerg',
-                    to        => [ qw( foo@example.com bar@example.org ) ],
-                    subject   => 'Big error!'.
-                  },
-            ],
+                [ [ 'Email::MailSend',
+                    min_level => 'emerg',
+                    to => [ qw( foo@example.com bar@example.org ) ],
+                    subject   => 'Big error!' ]
+                ],
           );
 
   $log->emerg("Something bad is happening");
