@@ -14,7 +14,7 @@ use base qw( Log::Dispatch::Email );
 
 use Mail::Sender ();
 
-our $VERSION = '2.25';
+our $VERSION = '2.26';
 
 sub new
 {
@@ -69,15 +69,16 @@ Log::Dispatch::Email::MailSender - Subclass of Log::Dispatch::Email that uses th
 
 =head1 SYNOPSIS
 
+  use Log::Dispatch;
+
   my $log =
       Log::Dispatch->new
           ( outputs =>
-            [ 'Email::MailSender' =>
-                  { min_level => 'emerg',
-                    to        => [ qw( foo@example.com bar@example.org ) ],
-                    subject   => 'Big error!'.
-                  },
-            ],
+                [ [ 'Email::MailSender',
+                    min_level => 'emerg',
+                    to => [ qw( foo@example.com bar@example.org ) ],
+                    subject   => 'Big error!' ]
+                ],
           );
 
   $log->emerg("Something bad is happening");
