@@ -7,7 +7,7 @@ use base qw( Log::Dispatch::File );
 
 use Fcntl qw(:DEFAULT :flock);
 
-our $VERSION = '2.25';
+our $VERSION = '2.26';
 
 
 sub _open_file
@@ -37,21 +37,20 @@ Log::Dispatch::File::Locked - Subclass of Log::Dispatch::File to facilitate lock
 
 =head1 SYNOPSIS
 
-  use Log::Dispatch::File::Locked;
+  use Log::Dispatch;
 
   my $log =
       Log::Dispatch->new
           ( outputs =>
-            [ 'File::Locked' =>
-                  { min_level => 'info',
+                [ [ 'File::Locked',
+                    min_level => 'info',
                     filename  => 'Somefile.log',
                     mode      => '>>',
-                    newline   => 1,
-                  },
-            ],
+                    newline   => 1 ]
+                ],
           );
 
-  $file->log( level => 'emerg', message => "I've fallen and I can't get up\n" );
+  $log->emerg( "I've fallen and I can't get up" );
 
 =head1 DESCRIPTION
 
