@@ -10,7 +10,7 @@ use base qw( Log::Dispatch::Output );
 use Params::Validate qw(validate BOOLEAN);
 Params::Validate::validation_options( allow_extra => 1 );
 
-our $VERSION = '2.25';
+our $VERSION = '2.26';
 
 
 sub new
@@ -61,11 +61,10 @@ Log::Dispatch::Screen - Object for logging to the screen
   my $log =
       Log::Dispatch->new
           ( outputs =>
-            [ 'Screen' =>
-                  { min_level => 'debug',
-                    stderr    => 1,
-                    newline   => 1
-                  },
+            [ [ 'Screen',
+                min_level => 'debug',
+                stderr    => 1,
+                newline   => 1 ]
             ],
           );
 
