@@ -12,7 +12,7 @@ Params::Validate::validation_options( allow_extra => 1 );
 
 use Sys::Syslog 0.16 ();
 
-our $VERSION = '2.25';
+our $VERSION = '2.26';
 
 sub new
 {
@@ -95,13 +95,11 @@ Log::Dispatch::Syslog - Object for logging to system log.
   my $log =
       Log::Dispatch->new
           ( outputs =>
-            [ 'Syslog' =>
-                  { min_level => 'info',
-                    ident => 'Yadda yadda'
-                  },
-            ],
+                [ [ 'Syslog',
+                    min_level => 'info',
+                    ident => 'Yadda yadda' ]
+                ]
           );
-  my $log = Log::Dispatch->new( outputs => [Syslog => {  }]);
 
   $log->emerg( "Time to die." );
 
